Improve this doc View Source

Modifies the default behavior of the html A tag so that the default action is prevented when the href attribute is empty.

This change permits the easy creation of action links with the `ngClick` directive without changing the location or causing page reloads, e.g.: `<a href="" ng-click="list.addItem()">Add Item</a>`

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <a>
      ...
      </a>